Flask-WTF
=========

.. image:: https://travis-ci.org/lepture/flask-wtf.svg?branch=master
   :target: https://travis-ci.org/lepture/flask-wtf
   :alt: Travis CI Status
.. image:: https://coveralls.io/repos/lepture/flask-wtf/badge.svg?branch=master
   :target: https://coveralls.io/r/lepture/flask-wtf
   :alt: Coverage Status

Simple integration of Flask and WTForms, including CSRF, file upload,
and reCAPTCHA.

Links
-----

* `Documentation <https://flask-wtf.readthedocs.io>`_
* `PyPI <https://pypi.python.org/pypi/Flask-WTF>`_
* `GitHub <https://github.com/lepture/flask-wtf>`_
